==> auger.ai-0.1.9-py3-none-any.whl: auger/cli/commands/cmd_model.py <==
import click

from auger.api.model import Model
from auger.cli.utils.context import pass_context
from auger.cli.utils.decorators import \
    error_handler, authenticated, with_project


class ModelCmd(object):

    def __init__(self, ctx):
        self.ctx = ctx

    @error_handler
    @authenticated
    @with_project(autocreate=False)
    def deploy(self, project, model_id, locally):
        Model(self.ctx, project).deploy(model_id, locally)

    @error_handler
    @authenticated
    @with_project(autocreate=False)
    def predict(self, project, filename, model_id, threshold, locally):
        Model(self.ctx, project).predict(filename, model_id, threshold, locally)


@click.group('model', short_help='Auger model management')
@pass_context
def command(ctx):
    """Auger model management"""
    ctx.setup_logger(format='')


@click.command('deploy', short_help='Deploy trained model.')
@click.argument('model-id', required=True, type=click.STRING)
@click.option('--locally', is_flag=True, default=False,
    help='Download and deploy trained model locally.')
@pass_context
def deploy(ctx, model_id, locally):
    """Deploy trained model."""
    ModelCmd(ctx).deploy(model_id, locally)

@click.command('predict', short_help='Predict with deployed model.')
@click.argument('filename', required=True, type=click.STRING)
@click.option('--threshold', '-t', default=None, type=float,
    help='Threshold.')
@click.option('--model-id', '-m', type=click.STRING, required=True,
    help='Deployed model id.')
@click.option('--locally', is_flag=True, default=False,
    help='Predict locally using Docker image to run model.')
@pass_context
def predict(ctx, filename, model_id, threshold, locally):
    """Predict with deployed model."""
    ModelCmd(ctx).predict(filename, model_id, threshold, locally)


@pass_context
def add_commands(ctx):
    command.add_command(deploy)
    command.add_command(predict)


add_commands()

==> auger.ai-0.2.0-py3-none-any.whl: auger/cli/commands/cmd_model.py <==
import click

from auger.api.model import Model
from auger.cli.utils.context import pass_context
from auger.cli.utils.decorators import \
    error_handler, authenticated, with_project


class ModelCmd(object):

    def __init__(self, ctx):
        self.ctx = ctx

    @error_handler
    @authenticated
    @with_project(autocreate=False)
    def deploy(self, project, model_id, locally):
        model_id = Model(self.ctx, project).deploy(model_id, locally)
        return {'model_id': model_id}

    @error_handler
    @authenticated
    @with_project(autocreate=False)
    def predict(self, project, filename, model_id, threshold, locally):
        predicted = Model(self.ctx, project).predict(
            filename, model_id, threshold, locally)
        return {'predicted': predicted}

    @error_handler
    @authenticated
    @with_project(autocreate=False)
    def actual(self, project, filename, model_id):
        Model(self.ctx, project).actual(
            filename, model_id)
        return ''

@click.group('model', short_help='Auger model management')
@pass_context
def command(ctx):
    """Auger model management"""
    ctx.setup_logger(format='')


@click.command('deploy', short_help='Deploy trained model.')
@click.argument('model-id', required=True, type=click.STRING)
@click.option('--locally', is_flag=True, default=False,
    help='Download and deploy trained model locally.')
@pass_context
def deploy(ctx, model_id, locally):
    """Deploy trained model."""
    ModelCmd(ctx).deploy(model_id, locally)

@click.command('predict', short_help='Predict with deployed model.')
@click.argument('filename', required=True, type=click.STRING)
@click.option('--threshold', '-t', default=None, type=float,
    help='Threshold.')
@click.option('--model-id', '-m', type=click.STRING, required=True,
    help='Deployed model id.')
@click.option('--locally', is_flag=True, default=False,
    help='Predict locally using Docker image to run model.')
@pass_context
def predict(ctx, filename, model_id, threshold, locally):
    """Predict with deployed model."""
    ModelCmd(ctx).predict(filename, model_id, threshold, locally)


@click.command('actual', short_help='Send actuals to deployed model.')
@click.argument('filename', required=True, type=click.STRING)
@click.option('--model-id', '-m', type=click.STRING, required=True,
              help='Deployed model id.')
@pass_context
def actual(ctx, filename, model_id):
    """Actual with deployed model."""
    ModelCmd(ctx).actual(filename, model_id)

@pass_context
def add_commands(ctx):
    command.add_command(deploy)
    command.add_command(predict)
    command.add_command(actual)


add_commands()
